/**
 * Metadata for audio. Not thread-safe.
 * @author yunya
 *
 */

package zero1hd.rhythmbullet.audio;

import com.badlogic.gdx.files.FileHandle;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.utils.Disposable;

public interface AudioMetadata extends Disposable {
	/**
	 * Load the album art data in to memory.
	 */
	public void loadAlbumCover();
	
	/**
	 * Unloads album art from memory.
	 */
	public void unloadAlbumCover();

	/**
	 * 
	 * @return the author for the song in the metadata.
	 */
	public String getAuthor();
	
	/**
	 * 
	 * @return the length of the song with proper fomatting.
	 */
	public String getLength();
	
	/**
	 * 
	 * @return the texture. Needs to be loaded before hand or else will return null.
	 */
	public Texture getAlbumCover();
	
	/**
	 * 
	 * @return returns the genre of the song stored in metadata.
	 */
	public String getGenre();
	
	/**
	 * 
	 * @return the filehandle.
	 */
	public FileHandle getFileHandle();
	
	/**
	 * 
	 * @return the extra metadata for RhythmBullet.
	 */
	public RhythmBulletMetadata getRBMetadata();
	
	/**
	 * This method effectively overwrites the mp3 file by creating a copy of it with the new metadata, and the deleting the old one, and renaming the new on to the old ones name.
	 * This is the suggested way of doing things by the library author in this thread: https://github.com/mpatric/mp3agic/issues/69
	 * @return true if succeeded in overwrite, and false if failed.
	 */
	public boolean flushRBMetadata();
	
	@Override
	public void dispose();
}
